@@ -1375,6 +1375,12 @@ _e_connman_element_get_properties_callback(void *user_data, DBusMessage *msg, DB
       _e_connman_element_listeners_call(element);
 }
 
+Eina_Bool
+e_connman_element_sync_properties_full(E_Connman_Element *element, E_DBus_Method_Return_Cb cb, const void *data)
+{
+   return e_connman_element_properties_sync_full(element, cb, data);
+}
+
 /**
  * Sync element properties with server.
  *
@@ -1388,7 +1394,7 @@ _e_connman_element_get_properties_callback(void *user_data, DBusMessage *msg, DB
  * @return @c EINA_TRUE on success, @c EINA_FALSE otherwise.
  */
 Eina_Bool
-e_connman_element_sync_properties_full(E_Connman_Element *element, E_DBus_Method_Return_Cb cb, const void *data)
+e_connman_element_properties_sync_full(E_Connman_Element *element, E_DBus_Method_Return_Cb cb, const void *data)
 {
    const char name[] = "GetProperties";
 
@@ -1413,7 +1419,7 @@ Eina_Bool
 e_connman_element_properties_sync(E_Connman_Element *element)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(element, EINA_FALSE);
-   return e_connman_element_sync_properties_full(element, NULL, NULL);
+   return e_connman_element_properties_sync_full(element, NULL, NULL);
 }
 
 /**
@@ -1786,6 +1792,12 @@ e_connman_element_property_type_get(const E_Connman_Element *element, const char
 
 void
 e_connman_element_list_properties(const E_Connman_Element *element, Eina_Bool (*cb)(void *data, const E_Connman_Element *element, const char *name, int type, const void *value), const void *data)
+{
+   e_connman_element_properties_list(element, cb, data);
+}
+
+void
+e_connman_element_properties_list(const E_Connman_Element *element, Eina_Bool (*cb)(void *data, const E_Connman_Element *element, const char *name, int type, const void *value), const void *data)
 {
    const E_Connman_Element_Property *p;
 
