@@ -23,7 +23,7 @@ DBusMessage * e_notify_marshal_get_capabilities_return(DBusMessage *method_call,
 void * e_notify_unmarshal_get_capabilities_return(DBusMessage *msg, DBusError *err);
 void   e_notify_free_get_capabilities_return(void *data);
 DBusMessage * e_notify_marshal_get_server_information();
-DBusMessage * e_notify_marshal_get_server_information_return(DBusMessage *method_call, const char *name, const char *vendor, const char *version);
+DBusMessage * e_notify_marshal_get_server_information_return(DBusMessage *method_call, const char *name, const char *vendor, const char *version, const char *spec_version);
 void * e_notify_unmarshal_get_server_information_return(DBusMessage *msg, DBusError *err);
 void   e_notify_free_get_server_information_return(void *data);
 DBusMessage * e_notify_marshal_close_notification(dbus_uint32_t id);
@@ -41,12 +41,23 @@ void e_notify_unmarshal_notify_actions(E_Notification *n, DBusMessageIter *iter)
 void e_notify_unmarshal_notify_hints(E_Notification *n, DBusMessageIter *iter);
 void e_notify_marshal_hint_image(DBusMessageIter *iter, E_Notification_Image *img);
 E_Notification_Image * e_notify_unmarshal_hint_image(DBusMessageIter *iter);
-
+void loginit(void);
+extern int _e_dbus_notify_log_dom;
 
 #ifndef E_DBUS_COLOR_DEFAULT
 #define E_DBUS_COLOR_DEFAULT EINA_COLOR_CYAN
 #endif
 
+#undef DBG
+#undef INF
+#undef WRN
+#undef ERR
+
+#define DBG(...) EINA_LOG_DOM_DBG(_e_dbus_notify_log_dom, __VA_ARGS__)
+#define INF(...) EINA_LOG_DOM_INFO(_e_dbus_notify_log_dom, __VA_ARGS__)
+#define WRN(...) EINA_LOG_DOM_WARN(_e_dbus_notify_log_dom, __VA_ARGS__)
+#define ERR(...) EINA_LOG_DOM_ERR(_e_dbus_notify_log_dom, __VA_ARGS__)
+
 struct E_Notification_Image
 {
   int   width;
@@ -61,11 +72,11 @@ struct E_Notification_Image
 struct E_Notification
 {
   int id;
-  char *app_name;
+  const char *app_name;
   unsigned int replaces_id;
-  char *app_icon;
-  char *summary;
-  char *body;
+  const char *app_icon;
+  const char *summary;
+  const char *body;
   int expire_timeout;
 
   Eina_List *actions;
@@ -73,9 +84,10 @@ struct E_Notification
   struct
   {
     char urgency;
-    char *category;
-    char *desktop;
-    char *sound_file;
+    const char *category;
+    const char *desktop;
+    const char *sound_file;
+    const char *image_path;
     char suppress_sound;
     int x, y;
     E_Notification_Image *image_data;
@@ -90,8 +102,8 @@ struct E_Notification
 
 struct E_Notification_Action 
 {
-  char *id;
-  char *name;
+  const char *id;
+  const char *name;
 };
 
 #endif
